@@ -5,26 +5,22 @@ This module provides the core MockSparkSession class for session management,
 maintaining compatibility with PySpark's SparkSession interface.
 """
 
-from typing import Any, Dict, List, Optional, Union, cast
+from typing import Any, Dict, List, Optional, Union, Tuple, cast
 from ...core.interfaces.session import ISession
-from ...core.interfaces.dataframe import IDataFrame, IDataFrameReader
+from ...core.interfaces.dataframe import IDataFrame
 from ...core.interfaces.storage import IStorageManager
 from ...core.exceptions.validation import IllegalArgumentException
 from ..context import MockSparkContext
 from ..catalog import MockCatalog
 from ..config import MockConfiguration, MockSparkConfig
 from ..sql.executor import MockSQLExecutor
-from mock_spark.storage import DuckDBStorageManager
+from mock_spark.backend.factory import BackendFactory
+from mock_spark.backend.protocols import StorageBackend
 from mock_spark.dataframe import MockDataFrame, MockDataFrameReader
 from ...spark_types import (
     MockStructType,
     MockStructField,
     StringType,
-    LongType,
-    DoubleType,
-    BooleanType,
-    ArrayType,
-    MapType,
 )
 
 
@@ -62,6 +58,7 @@ class MockSparkSession:
         enable_lazy_evaluation: bool = True,
         max_memory: str = "1GB",
         allow_disk_spillover: bool = False,
+        storage_backend: Optional[StorageBackend] = None,
     ):
         """Initialize MockSparkSession.
 
@@ -74,14 +71,19 @@ class MockSparkSession:
                        Default is '1GB' for test isolation.
             allow_disk_spillover: If True, allows DuckDB to spill to disk when memory is full.
                                  If False (default), disables spillover for test isolation.
+            storage_backend: Optional storage backend instance. If None, creates DuckDB backend.
         """
         self.app_name = app_name
-        self.storage = DuckDBStorageManager(
-            max_memory=max_memory,
-            allow_disk_spillover=allow_disk_spillover,
-        )
+        # Use dependency injection for storage backend
+        if storage_backend is None:
+            self.storage = BackendFactory.create_storage_backend(
+                backend_type="duckdb",
+                max_memory=max_memory,
+                allow_disk_spillover=allow_disk_spillover,
+            )
+        else:
+            self.storage = storage_backend
         from typing import cast
-        from ...core.interfaces.storage import IStorageManager
 
         self._catalog = MockCatalog(cast(IStorageManager, self.storage))
         self.sparkContext = MockSparkContext(app_name)
@@ -145,7 +147,7 @@ class MockSparkSession:
         self,
         data: Union[List[Dict[str, Any]], List[Any]],
         schema: Optional[Union[MockStructType, List[str]]] = None,
-    ) -> IDataFrame:
+    ) -> "MockDataFrame":
         """Create a DataFrame from data (mockable version)."""
         # Plugin hook: before_create_dataframe
         for plugin in getattr(self, "_plugins", []):
@@ -176,8 +178,8 @@ class MockSparkSession:
     def _real_createDataFrame(
         self,
         data: Union[List[Dict[str, Any]], List[Any]],
-        schema: Optional[Union[MockStructType, List[str]]] = None,
-    ) -> IDataFrame:
+        schema: Optional[Union[MockStructType, List[str], str]] = None,
+    ) -> "MockDataFrame":
         """Create a DataFrame from data.
 
         Args:
@@ -198,6 +200,11 @@ class MockSparkSession:
         if not isinstance(data, list):
             raise IllegalArgumentException("Data must be a list of dictionaries or tuples")
 
+        # Handle DDL schema strings
+        if isinstance(schema, str):
+            from ...core.ddl_adapter import parse_ddl_schema
+            schema = parse_ddl_schema(schema)
+
         # Handle list of column names as schema
         if isinstance(schema, list):
             fields = [MockStructField(name, StringType()) for name in schema]
@@ -310,23 +317,103 @@ class MockSparkSession:
     # NOTE: Validation and coercion logic extracted to DataValidator
     # See: mock_spark/core/data_validation.py
 
-    def sql(self, query: str) -> IDataFrame:
-        """Execute SQL query (mockable version)."""
-        return self._sql_impl(query)
+    def sql(self, query: str, *args: Any, **kwargs: Any) -> IDataFrame:
+        """Execute SQL query with optional parameters (mockable version).
+        
+        Args:
+            query: SQL query string with optional placeholders.
+            *args: Positional parameters for ? placeholders.
+            **kwargs: Named parameters for :name placeholders.
+        
+        Returns:
+            DataFrame with query results.
+            
+        Example:
+            >>> spark.sql("SELECT * FROM users WHERE age > ?", 18)
+            >>> spark.sql("SELECT * FROM users WHERE age > :min_age", min_age=18)
+        """
+        return self._sql_impl(query, *args, **kwargs)
 
-    def _real_sql(self, query: str) -> IDataFrame:
-        """Execute SQL query.
+    def _real_sql(self, query: str, *args: Any, **kwargs: Any) -> IDataFrame:
+        """Execute SQL query with optional parameters.
 
         Args:
-            query: SQL query string.
+            query: SQL query string with optional placeholders.
+            *args: Positional parameters for ? placeholders.
+            **kwargs: Named parameters for :name placeholders.
 
         Returns:
             DataFrame with query results.
 
         Example:
-            >>> df = spark.sql("SELECT * FROM users WHERE age > 18")
+            >>> df = spark.sql("SELECT * FROM users WHERE age > ?", 18)
+            >>> df = spark.sql("SELECT * FROM users WHERE name = :name", name="Alice")
         """
+        # Process parameters if provided
+        if args or kwargs:
+            query = self._bind_parameters(query, args, kwargs)
+        
         return self._sql_executor.execute(query)
+    
+    def _bind_parameters(self, query: str, args: Tuple[Any, ...], kwargs: Dict[str, Any]) -> str:
+        """Bind parameters to SQL query safely.
+        
+        Args:
+            query: SQL query with placeholders.
+            args: Positional parameters.
+            kwargs: Named parameters.
+        
+        Returns:
+            Query with parameters bound.
+        """
+        # Handle positional parameters (?)
+        if args:
+            # Count placeholders
+            placeholder_count = query.count('?')
+            if len(args) != placeholder_count:
+                raise ValueError(
+                    f"Number of parameters ({len(args)}) does not match "
+                    f"number of placeholders ({placeholder_count})"
+                )
+            
+            # Replace each ? with the corresponding parameter
+            result = query
+            for arg in args:
+                result = result.replace('?', self._format_param(arg), 1)
+            query = result
+        
+        # Handle named parameters (:name)
+        if kwargs:
+            for name, value in kwargs.items():
+                placeholder = f":{name}"
+                if placeholder not in query:
+                    raise ValueError(f"Parameter '{name}' not found in query")
+                query = query.replace(placeholder, self._format_param(value))
+        
+        return query
+    
+    def _format_param(self, value: Any) -> str:
+        """Format a parameter value for SQL safely.
+        
+        Args:
+            value: Parameter value.
+        
+        Returns:
+            Formatted parameter string.
+        """
+        if value is None:
+            return "NULL"
+        elif isinstance(value, str):
+            # Escape single quotes for SQL safety
+            escaped = value.replace("'", "''")
+            return f"'{escaped}'"
+        elif isinstance(value, bool):
+            return "TRUE" if value else "FALSE"
+        elif isinstance(value, (int, float)):
+            return str(value)
+        else:
+            # Default to string representation
+            return f"'{str(value)}'"
 
     def table(self, table_name: str) -> IDataFrame:
         """Get table as DataFrame (mockable version)."""
@@ -377,7 +464,7 @@ class MockSparkSession:
 
     def range(
         self, start: int, end: int, step: int = 1, numPartitions: Optional[int] = None
-    ) -> IDataFrame:
+    ) -> "MockDataFrame":
         """Create DataFrame with range of numbers.
 
         Args:
@@ -410,11 +497,11 @@ class MockSparkSession:
         except Exception:
             pass
 
-    def __enter__(self):
+    def __enter__(self) -> "MockSparkSession":
         """Context manager entry."""
         return self
 
-    def __exit__(self, exc_type, exc_val, exc_tb):
+    def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any) -> None:
         """Context manager exit."""
         self.stop()
 
@@ -427,68 +514,68 @@ class MockSparkSession:
         return MockSparkSession(self.app_name)
 
     # Mockable methods for testing
-    def mock_createDataFrame(self, side_effect=None, return_value=None):
+    def mock_createDataFrame(self, side_effect: Any = None, return_value: Any = None) -> None:
         """Mock createDataFrame method for testing."""
         if side_effect:
 
-            def mock_impl(*args, **kwargs):
+            def mock_impl(*args: Any, **kwargs: Any) -> Any:
                 raise side_effect
 
             self._createDataFrame_impl = mock_impl
         elif return_value:
 
-            def mock_impl(*args, **kwargs):
+            def mock_impl(*args: Any, **kwargs: Any) -> Any:
                 return return_value
 
             self._createDataFrame_impl = mock_impl
 
-    def mock_table(self, side_effect=None, return_value=None):
+    def mock_table(self, side_effect: Any = None, return_value: Any = None) -> None:
         """Mock table method for testing."""
         if side_effect:
 
-            def mock_impl(*args, **kwargs):
+            def mock_impl(*args: Any, **kwargs: Any) -> Any:
                 raise side_effect
 
             self._table_impl = mock_impl
         elif return_value:
 
-            def mock_impl(*args, **kwargs):
+            def mock_impl(*args: Any, **kwargs: Any) -> Any:
                 return return_value
 
             self._table_impl = mock_impl
 
-    def mock_sql(self, side_effect=None, return_value=None):
+    def mock_sql(self, side_effect: Any = None, return_value: Any = None) -> None:
         """Mock sql method for testing."""
         if side_effect:
 
-            def mock_impl(*args, **kwargs):
+            def mock_impl(*args: Any, **kwargs: Any) -> Any:
                 raise side_effect
 
             self._sql_impl = mock_impl
         elif return_value:
 
-            def mock_impl(*args, **kwargs):
+            def mock_impl(*args: Any, **kwargs: Any) -> Any:
                 return return_value
 
             self._sql_impl = mock_impl
 
     # Error simulation methods
-    def add_error_rule(self, method_name: str, error_condition, error_exception):
+    def add_error_rule(self, method_name: str, error_condition: Any, error_exception: Any) -> None:
         """Add error simulation rule."""
         self._error_rules[method_name] = (error_condition, error_exception)
 
-    def clear_error_rules(self):
+    def clear_error_rules(self) -> None:
         """Clear all error simulation rules."""
         self._error_rules.clear()
 
-    def reset_mocks(self):
+    def reset_mocks(self) -> None:
         """Reset all mocks to original implementations."""
         self._createDataFrame_impl = self._real_createDataFrame
         self._table_impl = self._real_table
         self._sql_impl = self._real_sql
         self.clear_error_rules()
 
-    def _check_error_rules(self, method_name: str, *args, **kwargs):
+    def _check_error_rules(self, method_name: str, *args: Any, **kwargs: Any) -> None:
         """Check if error should be raised for method."""
         if method_name in self._error_rules:
             for condition, exception in self._error_rules[method_name]:
@@ -496,13 +583,13 @@ class MockSparkSession:
                     raise exception
 
     # Integration with MockErrorSimulator
-    def _add_error_rule(self, method_name: str, condition, exception):
+    def _add_error_rule(self, method_name: str, condition: Any, exception: Any) -> None:
         """Add error rule (used by MockErrorSimulator)."""
         if method_name not in self._error_rules:
             self._error_rules[method_name] = []
         self._error_rules[method_name].append((condition, exception))
 
-    def _remove_error_rule(self, method_name: str, condition=None):
+    def _remove_error_rule(self, method_name: str, condition: Any = None) -> None:
         """Remove error rule (used by MockErrorSimulator)."""
         if method_name in self._error_rules:
             if condition is None:
@@ -512,7 +599,7 @@ class MockSparkSession:
                     (c, e) for c, e in self._error_rules[method_name] if c != condition
                 ]
 
-    def _should_raise_error(self, method_name: str, *args, **kwargs):
+    def _should_raise_error(self, method_name: str, *args: Any, **kwargs: Any) -> Any:
         """Check if error should be raised (used by MockErrorSimulator)."""
         if method_name in self._error_rules:
             for condition, exception in self._error_rules[method_name]:
@@ -522,6 +609,6 @@ class MockSparkSession:
 
 
 # Set the builder attribute on MockSparkSession
-from .builder import MockSparkSessionBuilder
+from .builder import MockSparkSessionBuilder  # noqa: E402
 
 MockSparkSession.builder = MockSparkSessionBuilder()
