@@ -79,6 +79,8 @@ class MockSQLExecutor:
                 return self._execute_create(ast)
             elif ast.query_type == "DROP":
                 return self._execute_drop(ast)
+            elif ast.query_type == "MERGE":
+                return self._execute_merge(ast)
             elif ast.query_type == "INSERT":
                 return self._execute_insert(ast)
             elif ast.query_type == "UPDATE":
@@ -116,11 +118,6 @@ class MockSQLExecutor:
             from ...dataframe import MockDataFrame
             from ...spark_types import (
                 MockStructType,
-                MockStructField,
-                StringType,
-                LongType,
-                DoubleType,
-                BooleanType,
             )
 
             # For now, create a simple DataFrame with one row
@@ -159,7 +156,7 @@ class MockSQLExecutor:
         where_conditions = components.get("where_conditions", [])
         if where_conditions:
             # Simple WHERE condition handling
-            condition = where_conditions[0]
+            where_conditions[0]
             # This is a mock implementation - real implementation would parse conditions
             pass
 
@@ -171,7 +168,7 @@ class MockSQLExecutor:
         # Apply GROUP BY
         group_by_columns = components.get("group_by_columns", [])
         if group_by_columns:
-            grouped_df = df.groupBy(*group_by_columns)
+            df.groupBy(*group_by_columns)
             # For now, convert grouped data back to DataFrame
             # In a real implementation, this would depend on the aggregation functions
             df = MockDataFrame([], MockStructType([]))
@@ -350,7 +347,66 @@ class MockSQLExecutor:
         Returns:
             DataFrame with DESCRIBE results.
         """
-        # Mock implementation
+        # Check for DESCRIBE HISTORY
+        query = ast.query if hasattr(ast, "query") else ""
+
+        if "HISTORY" in query.upper():
+            # DESCRIBE HISTORY table_name
+            import re
+
+            match = re.search(r"DESCRIBE\s+HISTORY\s+(\w+(?:\.\w+)?)", query, re.IGNORECASE)
+            if match:
+                table_name = match.group(1)
+
+                # Parse schema and table
+                if "." in table_name:
+                    schema_name, table_only = table_name.split(".", 1)
+                else:
+                    schema_name, table_only = "default", table_name
+
+                # Get table metadata
+                meta = self.session.storage.get_table_metadata(schema_name, table_only)  # type: ignore[attr-defined]
+
+                if not meta or meta.get("format") != "delta":
+                    from ...errors import AnalysisException
+
+                    raise AnalysisException(
+                        f"Table {table_name} is not a Delta table. "
+                        "DESCRIBE HISTORY can only be used with Delta format tables."
+                    )
+
+                version_history = meta.get("version_history", [])
+
+                # Create DataFrame with history
+                from ...dataframe import MockDataFrame
+                from ...spark_types import (
+                    MockStructType,
+                )
+                from typing import cast
+                from ...core.interfaces.dataframe import IDataFrame
+
+                # Build history rows
+                history_data = []
+                for v in version_history:
+                    # Handle both MockDeltaVersion objects and dicts
+                    if hasattr(v, "version"):
+                        row = {
+                            "version": v.version,
+                            "timestamp": v.timestamp,
+                            "operation": v.operation,
+                        }
+                    else:
+                        row = {
+                            "version": v.get("version"),
+                            "timestamp": v.get("timestamp"),
+                            "operation": v.get("operation"),
+                        }
+                    history_data.append(row)
+
+                # Return DataFrame using session's createDataFrame
+                return self.session.createDataFrame(history_data)
+
+        # Default DESCRIBE implementation
         from ...dataframe import MockDataFrame
         from ...spark_types import MockStructType
 
@@ -358,3 +414,140 @@ class MockSQLExecutor:
         from ...core.interfaces.dataframe import IDataFrame
 
         return cast(IDataFrame, MockDataFrame([], MockStructType([])))
+
+    def _execute_merge(self, ast: MockSQLAST) -> IDataFrame:
+        """Execute MERGE INTO query.
+
+        Args:
+            ast: Parsed SQL AST.
+
+        Returns:
+            Empty DataFrame (MERGE returns no results).
+        """
+        import re
+        from ...dataframe import MockDataFrame
+        from ...spark_types import MockStructType
+        from typing import cast
+        from ...core.interfaces.dataframe import IDataFrame
+
+        # Extract components
+        target_table = ast.components.get("target_table", "")
+        source_table = ast.components.get("source_table", "")
+        on_condition = ast.components.get("on_condition", "")
+        ast.components.get("target_alias")
+        ast.components.get("source_alias")
+        when_matched = ast.components.get("when_matched", [])
+        when_not_matched = ast.components.get("when_not_matched", [])
+
+        # Parse table names (schema.table)
+        if "." in target_table:
+            target_schema, target_name = target_table.split(".", 1)
+        else:
+            target_schema, target_name = "default", target_table
+
+        # Get target and source data
+        target_df = self.session.table(target_table)
+        target_data = target_df.collect()
+        {id(row): row.asDict() for row in target_data}
+
+        source_df = self.session.table(source_table)
+        source_data = source_df.collect()
+        source_data_list = [row.asDict() for row in source_data]
+
+        # Parse ON condition - simple equality for now
+        # Example: "t.id = s.id" or "t.id = s.id AND t.category = s.category"
+        condition_parts = []
+        for part in on_condition.split(" AND "):
+            part = part.strip()
+            match = re.match(r"(\w+)\.(\w+)\s*=\s*(\w+)\.(\w+)", part)
+            if match:
+                condition_parts.append(
+                    {
+                        "left_alias": match.group(1),
+                        "left_col": match.group(2),
+                        "right_alias": match.group(3),
+                        "right_col": match.group(4),
+                    }
+                )
+
+        # Track which target rows were matched
+        matched_target_ids = set()
+        updated_rows = []
+
+        # Process WHEN MATCHED clauses
+        if when_matched:
+            for target_row in target_data:
+                target_dict = target_row.asDict()
+
+                # Check if this target row matches any source row
+                for source_dict in source_data_list:
+                    matches = all(
+                        target_dict.get(cond["left_col"]) == source_dict.get(cond["right_col"])
+                        for cond in condition_parts
+                    )
+
+                    if matches:
+                        matched_target_ids.add(id(target_row))
+
+                        # Execute WHEN MATCHED action
+                        for clause in when_matched:
+                            if clause["action"] == "UPDATE":
+                                # Parse SET clause: "t.name = s.name, t.score = s.score"
+                                set_clause = clause["set_clause"]
+                                updated_row = target_dict.copy()
+
+                                for assignment in set_clause.split(","):
+                                    assignment = assignment.strip()
+                                    # Match: t.column = s.column or t.column = value
+                                    match = re.match(r"(\w+)\.(\w+)\s*=\s*(\w+)\.(\w+)", assignment)
+                                    if match:
+                                        target_col = match.group(2)
+                                        source_col = match.group(4)
+                                        updated_row[target_col] = source_dict.get(source_col)
+
+                                updated_rows.append(updated_row)
+                            elif clause["action"] == "DELETE":
+                                # Don't add to updated_rows (effectively deletes)
+                                pass
+                        break  # Only match first source row
+
+        # Add unmatched target rows (unchanged)
+        for target_row in target_data:
+            if id(target_row) not in matched_target_ids:
+                updated_rows.append(target_row.asDict())
+
+        # Process WHEN NOT MATCHED clauses (inserts)
+        if when_not_matched:
+            for source_dict in source_data_list:
+                # Check if this source row matches any target row
+                matched = False
+                for target_row in target_data:
+                    target_dict = target_row.asDict()
+                    matches = all(
+                        target_dict.get(cond["left_col"]) == source_dict.get(cond["right_col"])
+                        for cond in condition_parts
+                    )
+                    if matches:
+                        matched = True
+                        break
+
+                if not matched:
+                    # Execute WHEN NOT MATCHED action
+                    for clause in when_not_matched:
+                        if clause["action"] == "INSERT":
+                            # Parse: (id, name, score) VALUES (s.id, s.name, s.score)
+                            clause["insert_clause"]
+
+                            # Simple parsing: just insert all source columns
+                            # In production, would parse the column list and values
+                            updated_rows.append(source_dict.copy())
+
+        # Write merged data back to target table
+
+        self.session.storage.drop_table(target_schema, target_name)  # type: ignore[attr-defined]
+        self.session.storage.create_table(target_schema, target_name, target_df.schema.fields)  # type: ignore[attr-defined]
+        if updated_rows:
+            self.session.storage.insert_data(target_schema, target_name, updated_rows, mode="append")  # type: ignore[attr-defined]
+
+        # MERGE returns empty DataFrame
+        return cast(IDataFrame, MockDataFrame([], MockStructType([])))
