@@ -5,12 +5,11 @@ This module provides functionality to parse Spark SQL queries and convert them
 to SQLAlchemy statements, eliminating the need for raw SQL execution.
 """
 
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Dict, List, Union
 import sqlglot
 from sqlglot import exp
 from sqlalchemy import (
     Table,
-    Column,
     MetaData,
     select,
     insert,
@@ -30,7 +29,7 @@ from sqlalchemy import (
 from sqlalchemy.engine import Engine
 from sqlalchemy.sql import Select, Insert, Update, Delete
 from sqlalchemy.sql.elements import ColumnElement
-from .spark_function_mapper import get_sqlalchemy_function, is_supported_function
+from .spark_function_mapper import get_sqlalchemy_function
 
 
 class SQLTranslationError(Exception):
@@ -135,7 +134,7 @@ class SQLToSQLAlchemyTranslator:
             raise SQLTranslationError(f"Unsupported FROM clause: {type(table_exp).__name__}")
 
         # Build SELECT columns
-        select_cols = []
+        select_cols: List[Any] = []  # Can contain Table or ColumnElement
         has_star = False
         for projection in ast.expressions:
             if isinstance(projection, exp.Star):
@@ -173,17 +172,17 @@ class SQLToSQLAlchemyTranslator:
                     # Determine join type
                     join_kind = join_exp.args.get("kind", "").upper()
                     if join_kind == "LEFT":
-                        stmt = stmt.select_from(table).outerjoin(join_table, join_condition)
+                        stmt = stmt.select_from(table).outerjoin(join_table, join_condition)  # type: ignore[attr-defined]
                     elif join_kind == "RIGHT":
                         # SQLAlchemy doesn't have right join, need to swap tables
-                        stmt = stmt.select_from(join_table).outerjoin(table, join_condition)
+                        stmt = stmt.select_from(join_table).outerjoin(table, join_condition)  # type: ignore[attr-defined]
                     elif join_kind == "FULL":
-                        stmt = stmt.select_from(table).outerjoin(
+                        stmt = stmt.select_from(table).outerjoin(  # type: ignore[attr-defined]
                             join_table, join_condition, full=True
                         )
                     else:
                         # INNER join (default)
-                        stmt = stmt.select_from(table).join(join_table, join_condition)
+                        stmt = stmt.select_from(table).join(join_table, join_condition)  # type: ignore[attr-defined]
 
         # Add WHERE clause
         where = ast.find(exp.Where)
@@ -195,10 +194,28 @@ class SQLToSQLAlchemyTranslator:
         group_by = ast.find(exp.Group)
         if group_by:
             group_cols = []
-            for expr in group_by.expressions:
-                col = self._translate_expression(expr, table)
-                group_cols.append(col)
-            stmt = stmt.group_by(*group_cols)
+            # Check for GROUP BY ALL
+            if len(group_by.expressions) == 1:
+                expr_str = str(group_by.expressions[0]).strip().upper()
+                if expr_str == "ALL":
+                    # GROUP BY ALL: auto-detect non-aggregated columns
+                    # For simplicity, group by all non-aggregate selected columns
+                    for i, sel_expr in enumerate(ast.expressions):
+                        # Skip aggregate functions
+                        if not isinstance(sel_expr, (exp.Sum, exp.Count, exp.Avg, exp.Min, exp.Max)):
+                            col = self._translate_expression(sel_expr, table)
+                            group_cols.append(col)
+                else:
+                    for expr in group_by.expressions:
+                        col = self._translate_expression(expr, table)
+                        group_cols.append(col)
+            else:
+                for expr in group_by.expressions:
+                    col = self._translate_expression(expr, table)
+                    group_cols.append(col)
+            
+            if group_cols:
+                stmt = stmt.group_by(*group_cols)
 
         # Add HAVING
         having = ast.find(exp.Having)
@@ -210,14 +227,35 @@ class SQLToSQLAlchemyTranslator:
         order_by = ast.find(exp.Order)
         if order_by:
             order_cols = []
-            for ordered in order_by.expressions:
-                col = self._translate_expression(ordered.this, table)
-                if isinstance(ordered, exp.Ordered) and ordered.args.get("desc"):
-                    col = desc(col)
+            # Check for ORDER BY ALL
+            if len(order_by.expressions) == 1:
+                expr_str = str(order_by.expressions[0]).strip().upper()
+                # Remove DESC if present
+                expr_str_clean = expr_str.replace(" DESC", "").replace(" ASC", "").strip()
+                if expr_str_clean == "ALL":
+                    # ORDER BY ALL: order by all selected columns
+                    for sel_expr in ast.expressions:
+                        col = self._translate_expression(sel_expr, table)
+                        order_cols.append(asc(col))
                 else:
-                    col = asc(col)
-                order_cols.append(col)
-            stmt = stmt.order_by(*order_cols)
+                    for ordered in order_by.expressions:
+                        col = self._translate_expression(ordered.this, table)
+                        if isinstance(ordered, exp.Ordered) and ordered.args.get("desc"):
+                            col = desc(col)
+                        else:
+                            col = asc(col)
+                        order_cols.append(col)
+            else:
+                for ordered in order_by.expressions:
+                    col = self._translate_expression(ordered.this, table)
+                    if isinstance(ordered, exp.Ordered) and ordered.args.get("desc"):
+                        col = desc(col)
+                    else:
+                        col = asc(col)
+                    order_cols.append(col)
+            
+            if order_cols:
+                stmt = stmt.order_by(*order_cols)
 
         # Add LIMIT
         limit_exp = ast.find(exp.Limit)
@@ -499,7 +537,12 @@ class SQLToSQLAlchemyTranslator:
 
         elif isinstance(expr, exp.Substring):
             col = self._translate_expression(expr.this, table)
-            start = self._translate_expression(expr.args.get("start"), table)
+            start_arg = expr.args.get("start")
+            start: Any  # Can be BindParameter or ColumnElement
+            if start_arg is None:
+                start = literal(1)  # Default to position 1
+            else:
+                start = self._translate_expression(start_arg, table)
             length = expr.args.get("length")
             if length:
                 length_val = self._translate_expression(length, table)
